@@ -2,6 +2,19 @@ from rekuest.actors.vars import (
     get_current_assignation_helper,
     get_current_provision_helper,
 )
+from rekuest.api.schema import LogLevelInput
+from rekuest.actors.vars import (
+    get_current_assignation_helper,
+    get_current_provision_helper,
+)
+
+
+async def alog(message: str, level: LogLevelInput = LogLevelInput.DEBUG) -> None:
+    await get_current_assignation_helper().alog(level, message)
+
+
+async def plog(message: str, level: LogLevelInput = LogLevelInput.DEBUG) -> None:
+    await get_current_provision_helper().alog(level, message)
 
 
 def useUser() -> str:
