@@ -40,9 +40,12 @@ async def aexpand_arg(
         if port.nullable:
             return None
         else:
-            raise ExpandingError(
-                f"{port.key} is not nullable (optional) but your provided None"
-            )
+            if port.default is not None:
+                return port.default
+            else:
+                raise ExpandingError(
+                    f"{port.key} is not nullable (optional) but your provided None"
+                )
 
     if not isinstance(value, (str, int, float, dict, list)):
         raise ExpandingError(
